==================
Simulation Modules
==================



.. automodule:: pymoskito.simulation_modules
    :members:
    :private-members:
    :exclude-members: SimulationModule

    .. autoclass:: SimulationModule
        :members:

        .. autoproperty:: public_settings

        .. automethod:: calc_output(self)
